==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/KafkaRemoteBrokerConnectionSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Kafka RemoteBrokerConnectionSpec details
 * @property authentication The remote broker authentication methods.
 * @property endpoint The endpoint of remote broker to connect to.
 * @property tls TLS details for Remote broker Connection.
 */
public data class KafkaRemoteBrokerConnectionSpecArgs(
    public val authentication: Output<KafkaRemoteBrokerAuthenticationPropertiesArgs>,
    public val endpoint: Output<String>,
    public val tls: Output<KafkaRemoteBrokerConnectionTlsArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs.builder()
            .authentication(authentication.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .endpoint(endpoint.applyValue({ args0 -> args0 }))
            .tls(tls.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [KafkaRemoteBrokerConnectionSpecArgs].
 */
@PulumiTagMarker
public class KafkaRemoteBrokerConnectionSpecArgsBuilder internal constructor() {
    private var authentication: Output<KafkaRemoteBrokerAuthenticationPropertiesArgs>? = null

    private var endpoint: Output<String>? = null

    private var tls: Output<KafkaRemoteBrokerConnectionTlsArgs>? = null

    /**
     * @param value The remote broker authentication methods.
     */
    @JvmName("ydaklwqwvfsnejew")
    public suspend
    fun authentication(`value`: Output<KafkaRemoteBrokerAuthenticationPropertiesArgs>) {
        this.authentication = value
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("abgujigvpmsasvwr")
    public suspend fun endpoint(`value`: Output<String>) {
        this.endpoint = value
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("fuagqsjmrmuthutx")
    public suspend fun tls(`value`: Output<KafkaRemoteBrokerConnectionTlsArgs>) {
        this.tls = value
    }

    /**
     * @param value The remote broker authentication methods.
     */
    @JvmName("tqfombdjvdrrtfbu")
    public suspend fun authentication(`value`: KafkaRemoteBrokerAuthenticationPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument The remote broker authentication methods.
     */
    @JvmName("itlrbevaghclnutn")
    public suspend
    fun authentication(argument: suspend KafkaRemoteBrokerAuthenticationPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = KafkaRemoteBrokerAuthenticationPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("nfkuouijjdwrwtxi")
    public suspend fun endpoint(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("kisahqrewnofyojw")
    public suspend fun tls(`value`: KafkaRemoteBrokerConnectionTlsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tls = mapped
    }

    /**
     * @param argument TLS details for Remote broker Connection.
     */
    @JvmName("rbrdxekhnbpjmoqi")
    public suspend fun tls(argument: suspend KafkaRemoteBrokerConnectionTlsArgsBuilder.() -> Unit) {
        val toBeMapped = KafkaRemoteBrokerConnectionTlsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tls = mapped
    }

    internal fun build(): KafkaRemoteBrokerConnectionSpecArgs = KafkaRemoteBrokerConnectionSpecArgs(
        authentication = authentication ?: throw PulumiNullFieldException("authentication"),
        endpoint = endpoint ?: throw PulumiNullFieldException("endpoint"),
        tls = tls ?: throw PulumiNullFieldException("tls"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/inputs/KafkaRemoteBrokerConnectionSpecArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.inputs

import com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Kafka RemoteBrokerConnectionSpec details
 * @property authentication The remote broker authentication methods.
 * @property endpoint The endpoint of remote broker to connect to.
 * @property tls TLS details for Remote broker Connection.
 */
public data class KafkaRemoteBrokerConnectionSpecArgs(
    public val authentication: Output<KafkaRemoteBrokerAuthenticationPropertiesArgs>,
    public val endpoint: Output<String>,
    public val tls: Output<KafkaRemoteBrokerConnectionTlsArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs> {
    override fun toJava():
        com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs =
        com.pulumi.azurenative.iotoperationsmq.inputs.KafkaRemoteBrokerConnectionSpecArgs.builder()
            .authentication(authentication.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .endpoint(endpoint.applyValue({ args0 -> args0 }))
            .tls(tls.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [KafkaRemoteBrokerConnectionSpecArgs].
 */
@PulumiTagMarker
public class KafkaRemoteBrokerConnectionSpecArgsBuilder internal constructor() {
    private var authentication: Output<KafkaRemoteBrokerAuthenticationPropertiesArgs>? = null

    private var endpoint: Output<String>? = null

    private var tls: Output<KafkaRemoteBrokerConnectionTlsArgs>? = null

    /**
     * @param value The remote broker authentication methods.
     */
    @JvmName("bopfntowwqqdvnjh")
    public suspend
    fun authentication(`value`: Output<KafkaRemoteBrokerAuthenticationPropertiesArgs>) {
        this.authentication = value
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("oewynunuofaqpptt")
    public suspend fun endpoint(`value`: Output<String>) {
        this.endpoint = value
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("oljdmtguuikjdhra")
    public suspend fun tls(`value`: Output<KafkaRemoteBrokerConnectionTlsArgs>) {
        this.tls = value
    }

    /**
     * @param value The remote broker authentication methods.
     */
    @JvmName("mtqeqwfntimicvyx")
    public suspend fun authentication(`value`: KafkaRemoteBrokerAuthenticationPropertiesArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument The remote broker authentication methods.
     */
    @JvmName("jtepmfsiapbghead")
    public suspend
    fun authentication(argument: suspend KafkaRemoteBrokerAuthenticationPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = KafkaRemoteBrokerAuthenticationPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value The endpoint of remote broker to connect to.
     */
    @JvmName("xgbprybgvsoeoloe")
    public suspend fun endpoint(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.endpoint = mapped
    }

    /**
     * @param value TLS details for Remote broker Connection.
     */
    @JvmName("juhllwcflewmxbhq")
    public suspend fun tls(`value`: KafkaRemoteBrokerConnectionTlsArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tls = mapped
    }

    /**
     * @param argument TLS details for Remote broker Connection.
     */
    @JvmName("ctiwhnhgworthatw")
    public suspend fun tls(argument: suspend KafkaRemoteBrokerConnectionTlsArgsBuilder.() -> Unit) {
        val toBeMapped = KafkaRemoteBrokerConnectionTlsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.tls = mapped
    }

    internal fun build(): KafkaRemoteBrokerConnectionSpecArgs = KafkaRemoteBrokerConnectionSpecArgs(
        authentication = authentication ?: throw PulumiNullFieldException("authentication"),
        endpoint = endpoint ?: throw PulumiNullFieldException("endpoint"),
        tls = tls ?: throw PulumiNullFieldException("tls"),
    )
}
